<?php

/**
 * SF Webdesign
 *
 * @package SF Themes Demo
 * @author Franky https://www.stephan-frank.de/
 * @copyright 2020 SF Webdesign
 * @license https://opensource.org/licenses/artistic-license-2.0 Artistic License 2.0
 *
 * @version 1.0.0
 */

if (!defined('SMF'))
	die('Hacking attempt...');

function themedemo_load_theme()
{
	global $txt, $modSettings, $context, $settings;

	loadlanguage('Themesdemo');;
}

// Query the data of installed themes from the database
function load_themes_db()
{
  global $context, $settings, $txt, $modSettings, $smcFunc;

	$request = $smcFunc['db_query']('', '
		SELECT id_theme, variable, value
		FROM {db_prefix}themes
		WHERE variable IN ({string:name}, {string:theme_dir}, {string:theme_url}, {string:images_url})
		AND id_member = {int:no_member}
	  	AND id_theme IN ({array_string:known_themes})',
		array(
			'no_member' => 0,
			'name' => 'name',
			'theme_dir' => 'theme_dir',
			'theme_url' => 'theme_url',
			'images_url' => 'images_url',
			'known_themes' => explode(',', $modSettings['knownThemes']),
		)
	);
	$context['demo_themes'] = array();
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		if (!isset($context['demo_themes'][$row['id_theme']]))
			$context['demo_themes'][$row['id_theme']] = array(
				'id' => $row['id_theme'],
			);
		$context['demo_themes'][$row['id_theme']][$row['variable']] = $row['value'];
	}
	$smcFunc['db_free_result']($request);
}

// Query data for themesdemo info from the database
function load_themes_data()
{
	global $txt, $sourcedir, $context, $modSettings, $smcFunc, $settings;

	if (isset($_REQUEST['thdo']))
		$thdo = (int) $_REQUEST['thdo'];
	else
		$thdo = 1;

	$request = $smcFunc['db_query']('', '
		SELECT *
		FROM {db_prefix}themes_demo
		WHERE demo_id = {int:demo_id}',
		array(
			'demo_id' => $thdo,
		)
	);
	$context['demo_view'] = array();
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		$context['demo_view'][] = array(
			'id' 				=> $row['demo_id'],
			'themeid' 			=> $row['theme_id'],
			'themename' 		=> $row['theme_name'],
			'themeversion' 		=> $row['theme_version'],
			'smfversion' 		=> $row['smf_version'],
			'basis' 			=> $row['basis'],
			'assets' 			=> $row['assets'],
			'author' 			=> $row['author'],
			'webauthor' 		=> $row['web_author'],
			'support' 			=> $row['support'],
			'download' 			=> $row['download'],
		);
	}
	$smcFunc['db_free_result']($request);
}

// Permissions
function themedemo_load_permissions(&$permissionGroups, &$permissionList, &$leftPermissionGroups, &$hiddenPermissions, &$relabelPermissions)
{
	global $context;

	$permissionList['membergroup'] += array(
		'thdo_admin_manage' => array(false, 'thdo', 'thdo'),
		'thdo_view' => array(false, 'thdo', 'thdo'),
		'thdo_menu_view' => array(false, 'thdo', 'thdo'),
	);
}

function themedemo_menu_buttons(&$menu_buttons)
{
	global $txt, $boardurl;

	#You can use these settings to move the button around or even disable the button and use a sub button
	#Main menu button options

	#Where the button will be shown on the menu
	$button_insert = 'mlist';
	#before or after the above
	$button_pos = 'after';

	thdo_array_insert($menu_buttons, $button_insert,
		array(
			'thdo' => array(
				'title' => $txt['thdo_page_title'],
				'href' => $boardurl . '/Themesdemo/index.php',
				'show' => allowedTo('thdo_menu_view'),
				'sub_buttons' => array(
				),
			),
		)
		,$button_pos
	);
}


// Admin Center
function themedemo_admin_areas(&$admin_areas)
{
	global $txt, $modSettings, $scripturl, $helptxt;

	loadlanguage('Themesdemo');

	thdo_array_insert($admin_areas, 'maintenance',
		array(
		'thdo' => array(
			'title' => $txt['thdo_admin'],
			'permission' => array('thdo_admin_manage'),
			'areas' => array(
				'thdosset' => array(
					'label' => $txt['thdo_admin_page'],
					'file' => 'ManageThemesdemo.php',
					'function' => 'ThDoSettings',
					'icon' => 'thdo_generall.png',
				),
			),
		),
	));
}

// Button insert
function thdo_array_insert(&$input, $key, $insert, $where = 'after', $strict = false)
{
	$position = array_search($key, array_keys($input), $strict);

	// Key not found -> insert as last
	if ($position === false)
	{
		$input = array_merge($input, $insert);
		return;
	}

	if ($where === 'after')
		$position += 2;

	// Insert as first
	if ($position === 0)
		$input = array_merge($insert, $input);
	else
		$input = array_merge(
			array_slice($input, 0, $position),
			$insert,
			array_slice($input, $position)
		);
}

?>